%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                %
%  ijm.cls LaTeX Class for authors of            %
%  Innovative Journal of Mathematics             %
%                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ijm}
\newif\ifijm@twocolumns\ijm@twocolumnstrue
\newif\ifijm@printpagenumbers\ijm@printpagenumberstrue
\newif\ifijm@printlinenumbers\ijm@printlinenumbersfalse
\newif\ifijm@printpagerange\ijm@printpagerangetrue
\newif\ifijm@printbox\ijm@printboxfalse
\newif\ifijm@printabstract\ijm@printabstracttrue
\newif\ifijm@printkeywords\ijm@printkeywordstrue
\newif\ifijm@printpacs\ijm@printpacstrue
\newif\ifijm@printmsc\ijm@printmsctrue
\newif\ifijm@final\ijm@finaltrue
\newif\ifijm@pdf
\ijm@pdftrue
\pdfoutput=1

\newif\ifijm@firstaffiliation
\ijm@firstaffiliationtrue
\newdimen\ijm@tempdimen
\newcount\ijm@tempcount
\def\ijm@journalname{[Use option {\tt IJMt} to set name of journal.]}
\def\ijm@shortjournalname{[Use option {\tt IJMt} to set short name of journal.]}


\def\ijm@title{[Put the title here using command {\tt\char`\\title\char"7B text~of~title\char"7D}.]}
\let\ijm@shorttitle=\empty
\def\ijm@author{[Put the names of authors here using command {\tt\char`\\author\char"7B names of authors\char"7D}.]}
\let\ijm@shortauthor=\empty
\def\ijm@articletype{[Put the type of article here using command {\tt\char`\\articletype\char"7B type of article\char"7D}.]}
\def\ijm@year{[Put the year here using command {\tt\char`\\year\char"7B YYYY\char"7D}.]}
\def\ijm@issue{[Put the issue here using command {\tt\char`\\issue\char"7B NN\char"7D}.]}
\def\ijm@institute{[Put the names of institutes here using command {\tt\char`\\institute\char"7B names of institutes\char"7D}.]}
\let\ijm@msc=\empty
\let\ijm@pacs=\empty

%%%%%%%%%%%%%%%%%%%
\DeclareOption{IJMt}{
  \def\ijm@journalname{Innovative  Journal of {\bfseries Mathematics}}
  \def\ijm@shortjournalname{Innovative  Journal of Mathematics}
  \def\ijm@type{IJMt}
}
%%%%%%

%%%%%%%%%%%%%%%%%%%%

%%




\DeclareOption{PDF}{\ijm@pdftrue\pdfoutput=1\relax}
\DeclareOption{DVI}{\ijm@pdffalse\pdfoutput=0\relax}

\ProcessOptions
\ifijm@printabstract   \ijm@printboxtrue \fi
\ifijm@printkeywords  \ijm@printboxtrue  \fi
\ifijm@printpacs   \ifx\ijm@pacs\empty   \else     \ijm@printboxtrue   \fi \fi
\ifijm@printmsc   \ifx\ijm@msc\empty   \else     \ijm@printboxtrue   \fi \fi
\LoadClass[10pt,twoside,pre,nofootinbib,secnumarabic,balancelastpage,superscriptaddress,showpacs,showkeys]{revtex4}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  \pagestyle{myheadings}
  \def\contentsname{Contents}
  \def\listfigurename{List of Figures}
  \def\listtablename{List of Tables}
  \def\refname{References}
  \def\indexname{Index}
  \def\figurename{Figure}
  \def\tablename{Table}
  \def\partname{Part}
  \def\appendixname{Appendix}
  \def\abstractname{Abstract}


  \renewcommand*\email[1][E-mail: ]{\begingroup\sanitize@url\@email{#1}}%
  \chardef\*180
  \def\author#1{\expandafter\gdef\csname ijm@author\endcsname{#1}}
  \def\shortauthor#1{\expandafter\gdef\csname ijm@shortauthor\endcsname{#1}}
  \def\title#1{\expandafter\gdef\csname ijm@title\endcsname{#1}}
  \def\shorttitle#1{\expandafter\gdef\csname ijm@shorttitle\endcsname{#1}}
  \def\articletype#1{\expandafter\gdef\csname ijm@articletype\endcsname{#1}}
  \def\year#1{\expandafter\gdef\csname ijm@year\endcsname{#1}}
  \def\issue#1{\expandafter\gdef\csname ijm@issue\endcsname{#1}}
  \def\institute#1{\expandafter\gdef\csname ijm@institute\endcsname{#1}}
  \def\msc#1{\expandafter\gdef\csname ijm@msc\endcsname{#1}}
  \def\pacs#1{\expandafter\gdef\csname ijm@pacs\endcsname{#1}}
  \long\def\abstract#1{\expandafter\gdef\csname ijm@abstract\endcsname{#1}}
  \def\keywords#1{\expandafter\gdef\csname ijm@keywords\endcsname{#1}}
  
  \def\firstpage{\setcounter{page}}
  \def\lastpage#1{\expandafter\gdef\csname ijm@lastpage\endcsname{#1}}
  \def\titleblock@produce{%
    \def\thefootnote{\@fnsymbol\c@footnote}%
    \begingroup
    \null
    \vskip-\baselineskip
    \vskip-12mm
      \vbox to0pt{\vskip-12mm
      }
      \vskip-\baselineskip
      \vbox to0pt{\vskip19mm \vskip\textheight
      }
    
\vskip-\baselineskip  


%% Top Header:        
    \vbox to0pt{\vskip-5mm \fontsize{9pt}{8.4pt}\selectfont    
      \ijm@shortjournalname\\
       \footnotesize{v. xx no.  xx, }\ifijm@printpagerange\;\thepage-\ijm@lastpage\fi , (2022)\\
       doi:00.0000/00000000000000\\
       % \ijmhref[ijm@color]{https://www.sigmawings.com/journals}{https://www.sigmawings.com/journals}%
    }
    
    
    \vskip0.5mm
    
%%line at the header 
   % \leftline{\hskip-2mm\color{ijm@color}\vrule width\@rulewidth height.5pt}
 %  \vskip2pt
    
    
%% Journal Logo:   

   \begin{flushright}
   \vskip -3.2em
   \includegraphics[width=30mm]{logo.png}  
  % \hspace{0.3em} \qquad\\
  
  \sffamily
  \end{flushright}
  





%%%%%%%%%%%%%%%%%    
\vskip -1.2em
 \hspace{5.20in}\scriptsize{ISSN 2790-3370 (print)}
 \vskip 0.4em
  \hspace{5.20in}\scriptsize{ISSN 2790-3389 (online)}
%%%%%%%%%%%%%%%%%    
%%%%%%%%%%%%%%%%%    
    \newdimen\@rulewidth
    \@rulewidth=\textwidth
    \advance\@rulewidth by4mm
    \vskip2.5mm

%%%%%%%%%%%%%%%%%    
    \begin{flushleft}
      \sloppy\fontsize{19pt}{22.8pt}\selectfont\color{ijm@color}\textbf{\ijm@title}
    \end{flushleft}
    \vskip-\baselineskip
    \vskip6mm
    \begin{flushright}
       \fontsize{9pt}{8pt}\selectfont\textbf{\ijm@articletype}
    \end{flushright}%
   \vskip-\baselineskip
    \leftline{\hskip-2mm\color{ijm@color}\vrule width\@rulewidth height.5pt}
    \vskip-1.5\baselineskip
    \vskip2mm
    \null
    \begin{flushleft}
      \def\inst##1{$^\text{##1}$}%
      \def\email##1{\footnote{E-mail: ##1}}%
      \fontsize{10pt}{12pt}\selectfont\textbf{\ijm@author}
    \end{flushleft}
    \null
    \vskip-2.5\baselineskip
    \vskip2mm
    \null
    \begin{flushleft}
     $\null$%
     \def\inst##1{\parindent=10pt%
       \ifijm@firstaffiliation%
         \vskip-\baselineskip
         \ijm@firstaffiliationfalse
       \else
         \vskip2mm
       \fi%
       $\null$\llap{\hbox to\parindent{##1\hss}}\ignorespaces}%
       \fontsize{8pt}{9.5pt}\selectfont\color{grey}%
      \vskip-1\baselineskip\indent$\null$\ijm@institute
    \end{flushleft}
    \vskip-1.5\baselineskip
    \vskip10mm
     \ifijm@printbox%
	    \vskip-\baselineskip
	    \vskip1.5mm
	    \leftline{\hskip-2mm\color{ijm@color}\vrule width\@rulewidth height.5pt}
	    \vskip-.5pt
	    \fontsize{8pt}{10pt}\selectfont
	    \settowidth\ijm@tempdimen{\textbf{MSC:}\kern.5em}%
	    \ifijm@printabstract%
	      \settowidth\ijm@tempdimen{\textbf{Abstract:}\kern.5em}%
	    \fi%
	    \ifijm@printkeywords%
	      \settowidth\ijm@tempdimen{\textbf{Keywords:}\kern.5em}%
	    \fi%
	    \ifijm@printpacs%
		    \ifx\ijm@pacs\empty%
		    \else%
		      \settowidth\ijm@tempdimen{\textbf{PACS (2008):}\kern.5em}%
		    \fi%
		  \fi%

%%Abstract box		  
	    \leftline{%
	      \hskip-2mm\colorbox{abs}{%
	        \hskip1mm\vbox{%
	          \ifijm@printabstract%
		          \vskip2.6mm\hangindent\ijm@tempdimen
		           \fontsize{8pt}{10pt}\selectfont
		            $\null$\rlap{\textbf{Abstract:}}\kern\ijm@tempdimen%
                    \selectfont\ijm@abstract
		            \vskip1mm
		        \fi%
	          \ifijm@printmsc%
		          \ifx\ijm@msc\empty\else
		            \vskip1mm\hangindent\ijm@tempdimen
		             \fontsize{8pt}{10pt}\selectfont
		              $\null$\rlap{\textbf{MSC:}}\kern\ijm@tempdimen%
		              \selectfont\ijm@msc
  		            \vskip1mm
		          \fi%
		        \fi%
		        \ifijm@printpacs%
		          \ifx\ijm@pacs\empty\else
		            \vskip1mm\hangindent\ijm@tempdimen
		              \fontsize{8pt}{10pt}\selectfont
		              $\null$\rlap{\textbf{PACS (2008):}}\kern\ijm@tempdimen%
		              \selectfont\ijm@pacs
  		            \vskip1mm
		          \fi%
		        \fi%
		        \ifijm@printkeywords%
		          \vskip1mm\hangindent\ijm@tempdimen
		          \fontsize{8pt}{10pt}\selectfont
		            $\null$\rlap{\textbf{Keywords:}}\kern\ijm@tempdimen%
		            \selectfont\ijm@keywords\\[1mm]%
		           % \copyright\;
		            %\selectfont
		           %Sigmawings, All rights reserved.
		          %\vskip1mm
		          
		        \fi%
            %\vskip1.6mm
	        }%
	      \hskip1mm}%
	    }%
	  \fi%
	  
    \vskip-2mm
    \leftline{\hskip-2mm\color{ijm@color}\vrule width\@rulewidth height.5pt}
    \vskip10mm
    \endgroup
    \gdef\thefootnote{\@arabic\c@footnote}
    \global\c@footnote=0
  }%

  \def\@hangfrom@section#1#2#3{\@hangfrom{#1#2}{#3}}%
  \def\section{\@startsection{section}{1}{\z@}{19\p@}{12\p@}
    {\noindent\fontsize{15pt}{17pt}	\bfseries \selectfont$\null$\color{ijm@color}}}
  \def\subsection{\@startsection{subsection}{2}{\z@}{14\p@}{8\p@}
   {\noindent\fontsize{12\p@}{14\p@} \bfseries \selectfont$\null$\color{ijm@color}}}
  \def\subsubsection{\@startsection {subsubsection}{3}{\z@}{8\p@}{4\p@}
    {\noindent\fontsize{10pt}{12pt}	\bfseries \selectfont$\null$\color{ijm@color}}}
  \def\paragraph{\@startsection{paragraph}{4}{\z@}{12\p@}{2\p@}
    {\noindent\fontsize{9pt}{12pt}	\bfseries \itshape \selectfont$\null$\color{ijm@color}}}
  \def\subparagraph{\@startsection{subparagraph}{5}{\z@}{6\p@}{\z@}%
    {\normalfont\normalsize\bfseries}}
  \c@tocdepth=1
  \c@secnumdepth=3

  \def\footnoterule{\kern-7.5mm {\color{ijm@color}\hbox{\hskip-2mm\vrule width79.8mm height.5pt}}\kern2mm}
  \renewcommand\@makefntext[1]{\parindent0\p@\relax\indent%
    \rmfamily\it\fontsize{9}{10.8}\selectfont%
    \@makefnmark\enspace#1}
  \def\@fnsymbol#1{\ensuremath{\ifcase#1\or *\or \dagger\or \ddagger\or
    \mathsection\or \mathparagraph\or \|\or **\or \dagger\dagger
    \or \ddagger\ddagger \else\@ctrerr\fi}}
  \def\thefootnote{\@arabic\c@footnote}
  \footnotesep=2mm
  \gdef\@reinserts{%
    \ifvoid\footins\else\insert\footins{\unvbox\footins}\fi
    \ifvbox\@kludgeins\insert\@kludgeins
                        {\unvbox\@kludgeins}\fi
  }
  
  
  \def\thetable{\@arabic\c@table}
  \abovecaptionskip=5.5mm
  \belowcaptionskip2mm
  \long\def\@makecaption#1#2{%
    \par
    \vskip\abovecaptionskip
    \begingroup
    \small\rmfamily
    \sbox\@tempboxa{%
      \let\\\heading@cr
        \fontsize{9pt}{8.4pt} \bfseries \selectfont%
      \settowidth\ijm@tempdimen{#1.\enspace}%
      \hangindent\ijm@tempdimen{\color{ijm@color}#1.\enspace}%
    \fontsize{7pt}{8.4pt} \selectfont%
      #2\par
    }%
    \@ifdim{\wd\@tempboxa >\hsize}{%
      \begingroup
      \samepage
      \flushing
      \let\footnote\@footnotemark@gobble
      \fontsize{9pt}{8.4pt}  \selectfont%
      \settowidth\ijm@tempdimen{#1.\enspace}%
      \hangindent\ijm@tempdimen{\color{ijm@color}#1.\enspace}%
       \fontsize{7pt}{8.4pt}\selectfont%
      #2\par
      \endgroup
    }{%
      \global \@minipagefalse
      \hb@xt@\hsize{\unhbox\@tempboxa\hfil}%
    }%
    \endgroup
    \vskip\belowcaptionskip
  }%

  \renewenvironment{widetext@grid}{%
    \par\ignorespaces
    \setbox\widetext@top\vbox{%
    \vskip10\p@
    \hb@xt@\hsize{%
      \leaders\hrule\hfil
      \vrule\@height6\p@
    }%
    \vskip6\p@
    }%
    \setbox\widetext@bot\hb@xt@\hsize{%
      \vrule\@depth6\p@
      \leaders\hrule\hfil
    }%
    \onecolumngrid
    \dimen@\ht\widetext@top\advance\dimen@\dp\widetext@top
    \cleaders\box\widetext@top\vskip\dimen@
    \let\set@footnotewidth\set@footnotewidth@ii
  }{%
    \vskip6\p@
    \setbox\widetext@bot\vbox{%
    \hb@xt@\hsize{\hfil\box\widetext@bot}%
    \vskip10\p@
    }%
    \dimen@\ht\widetext@bot\advance\dimen@\dp\widetext@bot
    \cleaders\box\widetext@bot\vskip\dimen@
    \twocolumngrid\global\@ignoretrue
    \@endpetrue
  }%

  \def\bibfont{\normalsize}
	\def\bibsection{%
	  \def\section{\@startsection{section}{1}{\z@}{5.5mm}{5mm}
	    {\noindent\fontsize{11pt}{11pt}\selectfont$\null$\color{ijm@color}\vskip6mm \hbox{\hskip-2mm\color{ijm@color}\vrule width79.8mm height.5pt}\vskip-10mm }}
	  \let\@hangfroms@section\@hang@froms
	  \section*{\refname}%
	  \ifijm@twocolumns
	  \else
	    \vskip-\baselineskip
	    \vskip4mm
	    \null
	  \fi
	  \@nobreaktrue
	}
	
%%%%%%%%%%%%%%%%%%%%%%%
  \def\tiny{\fontsize{5pt}{6pt}\selectfont}
  \def\scriptsize{\fontsize{6pt}{7pt}\selectfont}
  \def\footnotesize{\fontsize{7pt}{8pt}\selectfont}
  \def\small{\fontsize{8pt}{10pt}\selectfont}
  \def\normalsize{\fontsize{9pt}{18pt}\selectfont}
  \def\large{\fontsize{10pt}{12pt}\selectfont}
  \def\Large{\fontsize{12pt}{14pt}\selectfont}
  \def\LARGE{\fontsize{15pt}{16pt}\selectfont}
  \def\huge{\fontsize{17pt}{20pt}\selectfont}
  \def\Huge{\fontsize{20pt}{24pt}\selectfont}
  \def\*{$\bullet$ \relax}

\RequirePackage{amsmath}
  \abovedisplayskip=16ptplus4ptminus8pt
  \abovedisplayshortskip=1ptplus4pt
  \belowdisplayskip=16ptplus4ptminus8pt
  \belowdisplayshortskip=8ptplus6ptminus5pt


\RequirePackage{amscd, amsfonts, amssymb, url, enumerate, mathrsfs}

\RequirePackage{amsthm}
  \newtheoremstyle{itstyle}
    {16pt plus6pt}
    {16pt plus6pt}
    {\rmfamily\it\fontsize{9}{11}\selectfont}
    {0pt}
    {\fontsize{10}{11} \bfseries \selectfont\color{ijm@color}$\null$}
    {\newline\nobreak}
    {0pt}
    {\indent#1\hbox{ }#2\thmnote{\hbox{ }(#3)}. \ }
  \newtheoremstyle{rmstyle}
    {16pt plus6pt}
    {16pt plus6pt}
    {\rmfamily\fontsize{9}{11}\selectfont}
    {0pt}
    {\fontsize{10}{11}\bfseries \selectfont\color{ijm@color}$\null$}
    {\newline\nobreak}
    {0pt}
    {\indent#1\hbox{ }#2\thmnote{\hbox{ }(#3)}. \ }
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%    
  \theoremstyle{itstyle}
  \newtheorem{theorem}{Theorem}[section]
  \newtheorem{lemma}{Lemma}[section]
  \newtheorem{proposition}{Proposition}[section]
  \newtheorem{claim}{Claim}[section]
  \newtheorem{fact}{Fact}[section]
  \newtheorem{corollary}{Corollary}[section]
  \newtheorem{assumption}{Assumption}[section] %???
  \newtheorem{algoritheorem}{Algoritheorem}[section] %???
  \theoremstyle{rmstyle}
  \newtheorem{remark}{Remark}[section]
  \newtheorem{example}{Example}[section]
  \newtheorem{question}{Question}[section]
  \newtheorem{problem}{Problem}[section]
  \newtheorem{conjecture}{Conjecture}[section]
  \newtheorem{definition}{Definition}[section]
  \newtheorem{axiom}{Axiom}[section] %???
  \def\proofname{{\fontsize{10}{11}\selectfont\color{ijm@color}$\null$Proof. \ }}

\ifijm@pdf
  \RequirePackage[pdftex]{graphicx}
\else
  \RequirePackage[dvips]{graphicx}
\fi


%%%%%%%%%%%%%%
\RequirePackage{color}
  \definecolor{ijm@color}{rgb}{1,0,0}
  \definecolor{abs}{rgb}{1,.9,.9}
  \definecolor{grey}{rgb}{.3,.3,.3}



\def\IJMt{IJMt}
\ifx\ijm@type\IJMt
  \definecolor{ijm@color}{rgb}{0.0, 0.4, 0.0}%{rgb}{0.28515625,0.5234375,0.140625}
  \definecolor{abs}{rgb}{0.953125,0.96484375,0.98046875}%{0.96875,0.97265625,0.95703125}
\fi
%%%%%
\newcommand{\ijmhref}[3][blue]{\href{#2}{\color{#1}{#3}}}% %%???



\ifijm@pdf
  \ifijm@final
    \RequirePackage[pdftex,colorlinks=true,citecolor=blue,linkcolor=blue,final]{hyperref}
  \else
    \RequirePackage[pdftex,colorlinks=true,citecolor=blue,linkcolor=blue,draft]{hyperref}
 \fi
\else
  \ifijm@final
    \RequirePackage[ps2pdf,colorlinks=true,citecolor=blue,linkcolor=blue,final]{hyperref}
  \else
    \RequirePackage[ps2pdf,colorlinks=true,citecolor=blue,linkcolor=blue,draft]{hyperref}
  \fi
  
  
  
\fi
\usepackage{hypernat} 
\paperwidth=210mm
\paperheight=277mm
\ifijm@pdf
  \pdfpagewidth=\paperwidth
  \pdfpageheight=\paperheight
\fi



\textwidth=159.95mm
\textheight=222.5mm

\newdimen\ijm@textwidth
\ijm@textwidth=\textwidth

\hoffset=-1in
\advance\hoffset by.5\paperwidth
\advance\hoffset by-.5\textwidth

\voffset=-1in
\advance\voffset by.5\paperheight
\advance\voffset by-.5\textheight
\advance\voffset by-15mm

\evensidemargin=0mm
\oddsidemargin=0mm

\topmargin=0pt

\headheight=40pt
\headsep=0pt

\marginparsep=0pt
\marginparwidth=0pt
\marginparpush=0pt

\parindent=0pt

\baselineskip=12pt

\footskip=30pt

\def\ijm@linenumbers{}
\def\ijm@titlehead{\vbox to40pt{\hsize=.5\ijm@textwidth \advance\hsize by.5\columnsep
  \ijm@linenumbers%
}}

\def\ijm@oddhead{\vbox to40pt{%
  \ifijm@twocolumns
	  \hsize=.5\ijm@textwidth
	  \advance\hsize by.5\columnsep
  \else
    \hsize=\ijm@textwidth
  \fi
  \ijm@linenumbers%
  \def\email##1{}\def\inst##1{}%
  \vbox to20pt{%
    \raggedright%
    \fontsize{7pt}{8.4pt}\selectfont\color{grey}%
    \ifx\ijm@shortauthor\empty%
      \ijm@author%
    \else%
      \ijm@shortauthor%
    \fi%
    \vss%
  }%
  \hbox to\ijm@textwidth{\hskip-2mm\color{ijm@color}\vrule width\textwidth height.5pt\hss}%
  \vskip1mm
  \hskip.5\ijm@textwidth\hbox to.5\ijm@textwidth{\hskip.5\columnsep\color{white}\vrule width\textwidth height2.962mm\hss}%
  \vss%
}}

\def\ijm@evenhead{\vbox to40pt{\hsize=\ijm@textwidth
  \ijm@linenumbers%
  \def\email##1{}\def\inst##1{}%
  \vbox to20pt{%
    \raggedleft%
    \fontsize{7pt}{8.4pt}\selectfont\color{grey}%
    \ifx\ijm@shorttitle\empty%
      \ijm@title%
    \else%
      \ijm@shorttitle%
    \fi%
    \vss%
  }%
  
  
  \hbox to\ijm@textwidth{\hss\color{ijm@color}\vrule width\textwidth height.5pt\hskip-2mm}%
  \vskip1mm
  \hbox to.5\ijm@textwidth{\hss\color{white}\vrule width\textwidth height2.962mm\hskip.5\columnsep}%
  \vss%
}}


%%%%%%%%%%%%%%%%%

\def\ijm@oddfoot{\ifijm@printpagenumbers%
    \hfill\rlap{\hskip.7cm{\colorbox{white}{\hbox to1.7cm{%
    \hss\usefont{T1}{square721exeu}{m}{n}\fontsize{7pt}{8.4pt}\selectfont\color{black}\thepage\hss}}}}%
  \fi}

\def\ijm@evenfoot{\ifijm@printpagenumbers%
    \llap{{\colorbox{white}{\hbox to1.7cm{%
    \hss\fontsize{7pt}{8.4pt}\selectfont\color{black}\thepage\hss}}\hskip.7cm}}%
  \fi}

\def\ps@myheadings{
  \let\@oddhead=\ijm@oddhead
  \let\@oddfoot=\ijm@oddfoot
  \let\@evenhead=\ijm@evenhead
  \let\@evenfoot=\ijm@evenfoot
}

\def\ps@titlepage{
  \let\@oddhead=\ijm@titlehead
  \let\@oddfoot=\ijm@oddfoot
  \let\@evenhead=\ijm@titlehead
  \let\@evenfoot=\ijm@evenfoot
}

\ps@myheadings

\AtBeginDocument{%
  \renewcommand{\familydefault}{\rmdefault}
  \fontfamily{\familydefault}

  \thispagestyle{titlepage}
  \def\ijm@lastpage{{\color{red}[Compile the document one more time to update number of the last page!]}}

  \newread\ijm
  \openin\ijm=\jobname.ijm
  \ifeof\ijm \else\input\jobname.ijm \fi

  \newwrite\ijm
  \immediate\openout\ijm=\jobname.ijm

  \rm\normalsize
}

\AtEndDocument{
  \immediate\write\ijm{\string\lastpage{\thepage}}
  \immediate\closeout\ijm
}
\endinput
